abacusai.chatllm_project — AbacusAI documentation

# abacusai.chatllm_project

## Classes

`ChatllmProject` | ChatLLM Project

## Module Contents

class abacusai.chatllm_project.ChatllmProject(client, chatllmProjectId=None, name=None, description=None, customInstructions=None, createdAt=None, updatedAt=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  ChatLLM Project

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - chatllmProjectId (id) – The ID of the chatllm project.

    - name (str) – The name of the chatllm project.

    - description (str) – The description of the chatllm project.

    - customInstructions (str) – The custom instructions of the chatllm project.

    - createdAt (str) – The creation time of the chatllm project.

    - updatedAt (str) – The update time of the chatllm project.

  chatllm_project_id = None
  name = None
  description = None
  custom_instructions = None
  created_at = None
  updated_at = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict